import QtQuick 2.4
import Trogl 1.0

Item{
    id: _Slider
    width: uiSettings.slbw
    height: uiSettings.slbh
    property real minVal: 0
    property real maxVal: 100
    property real curVal: 0
    property alias tumb: _Thumb
    property bool intMode: false

    onCurValChanged: {
        curVal = Math.max(Math.min(curVal, maxVal), minVal)
        updateThumbPos()
    }
    onMinValChanged: updateRange()
    onMaxValChanged: updateRange()

    function updateRange() {
        minVal = Math.min(minVal, maxVal)
        maxVal = Math.max(minVal, maxVal)
        curVal = Math.min(Math.max(curVal, minVal), maxVal)
    }

    function valFromY(newY)
    {
        var thh = _Thumb.height/2;
        var cropY = Math.min(Math.max(newY, thh), _WorkspaceBG.height - thh);
        var tmpVal = minVal + (maxVal - minVal + 1) * (1.0 - (cropY - thh) / (_WorkspaceBG.height - _Thumb.height));
        curVal = intMode?Math.floor(tmpVal):tmpVal;
    }
    function updateThumbPos(){
        _Thumb.y = ((_WorkspaceBG.height - _Thumb.height)*(1.0 - (curVal - minVal)/(maxVal - minVal))).toFixed()
    }
    Rectangle {
        id: _WorkspaceBG
        anchors.fill: parent
        radius: _Slider.tumb.radius
        color: "#00000000"
        border.width: uiSettings.slcw
        border.color: Skin.sliderCtrlBorder
    }
    Button {
        id: _Thumb
        anchors.horizontalCenter: _WorkspaceBG.horizontalCenter
        width: parent.width
        height: Math.max((_WorkspaceBG.height/(maxVal - minVal + 1)).toFixed(), _WorkspaceBG.height/6);
        radius: uiSettings.slrb
        backGround.gradient: Skin.sliderCtrlThumb
        onMoved: valFromY(y + my)
    }
}
