import QtQuick 2.4

Item {
    id: _control
    width: ui.c*4
    height: ui.c*2
    property alias model: c1.model
    property int current: -1
    property alias selected: c1.currentIndex
    property alias orientation: c1.orientation
    property alias layoutDidection: c1.layoutDirection
    property alias verticalLayoutDirection: c1.verticalLayoutDirection

    Component.onCompleted: updateCurrentView()
    onCurrentChanged: updateCurrentView()
    signal finished(int index)

    function updateCurrentView() {
        var curItem = model.get(current)
        if(curItem)
        {
            text.text = curItem.caption
            img.source = curItem.url
        }
    }
    function showList()
    {
        ma.trackInput = true
        c1.x = 0;//_control.width + c1.spacing
        c1.y = 0
        c1.width = c1.contentWidth
        c1.height = c1.contentHeight

        if(orientation === ListView.Vertical)
        {
            if(verticalLayoutDirection === ListView.BottomToTop)
                c1.y = - c1.height
            else
                c1.y = _control.height - c1.height
        }
        else
        {
            if(layoutDidection === ListView.RightToLeft)
                c1.x = _control.width - c1.width
        }
        c1.currentIndex = -1
        c1.visible = true
    }
    function hide()
    {
        c1.visible = false
        ma.trackInput = false
        if(c1.currentIndex !== -1)
            finished(c1.currentIndex)
    }
    Rectangle {
        id: background
        anchors.fill: parent
        color: Skin.ch
        visible: false
        opacity: 0.2
        radius: ui.c/8
    }

    Text {
        id: text
        font.family: "Ubuntu"
        font.bold: true
        style: Text.Normal
        color: Skin.cm
        anchors.centerIn: parent
    }
    TroglImage {
        id: img
        anchors.fill: parent
    }

    MouseArea {
        id: ma
        property bool trackInput: false
        width: 10000
        height: 10000
        x: -5000
        y: -5000
        visible: c1.visible
        onClicked: {
            c1.visible = false
        }
    }
    MouseArea {
        anchors.fill: parent
        onPressAndHold: {showList();c1.select(mouseX, mouseY)}
        onMouseXChanged: c1.select(mouseX, mouseY)
        onMouseYChanged: c1.select(mouseX, mouseY)
        onClicked: showList()
        onReleased: {
            if(ma.trackInput)
                hide()
            background.visible = false
        }
    }

    ListView {
        id: c1
        spacing: ui.i
        visible: false
        interactive: false
        model: ListModel{}

        delegate: Button
        {
            bgHighLight: Skin.buttonGrayBorderNormal
            width: _control.width
            height: _control.height
            text.text: (url===undefined)?"":caption
            text.color: Skin.cm
            img.source: url?url:""
            active: (_control.current === index)
            onClicked: {
                selected = index
                hide()
            }
        }
        highlightMoveVelocity: 1000000
        highlight: Rectangle {
            width: _control.width
            height: _control.height
            radius: ui.c/8
            color: Skin.ch
            opacity: 0.2
        }

        function select(mx, my) {
            if(ma.trackInput)
            {
                var cPos = mapFromItem(_control, mx, my)
                if(verticalLayoutDirection === ListView.BottomToTop)
                    cPos.y -= height
                if(layoutDidection === ListView.RightToLeft)
                    cPos.x -= width
                var newInd = indexAt(cPos.x, cPos.y)
                currentIndex = indexAt(cPos.x, cPos.y)
                cPos = background.mapFromItem(_control, mx, my)
                background.visible = background.contains(cPos)
            }
            else
                background.visible = false
        }
    }
}
